define([
    './optionContainer.js'
    ,'./optionDeleteButton.js'
    ,'./optionPlusButton.js'
    , './vpSuggestInputText_apiblock.js'
    , './optionInput.js'
    , './optionSelectBox.js'
    , './vpLineNumberTextArea_apiblock.js'

], function ( MakeOptionContainer
              , MakeOptionDeleteButton
              , MakeOptionPlusButton
              , MakeVpSuggestInputText_apiblock
              , MakeOptionInput
              , MakeOptionSelectBox
              , MakeLineNumberTextArea_apiblock

            ) {

    return {
        MakeOptionContainer
        , MakeOptionDeleteButton
        , MakeOptionPlusButton
        , MakeVpSuggestInputText_apiblock
        , MakeOptionInput
        , MakeOptionSelectBox
        , MakeLineNumberTextArea_apiblock

    }
});
